==> qt-creator-2.2.0-src.zip: qt-creator-2.2.0-src/src/plugins/qmldesigner/designmodecontext.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef DESIGNMODECONTEXT_H
#define DESIGNMODECONTEXT_H

#include <coreplugin/icontext.h>
#include <QList>

QT_BEGIN_NAMESPACE
class QWidget;
QT_END_NAMESPACE

namespace QmlDesigner {

class FormEditorWidget;

namespace Internal {

class DesignModeWidget;

/**
  * Bauhaus Design mode context object
  */
class DesignModeContext : public Core::IContext
{
public:
    DesignModeContext(DesignModeWidget *widget);
    ~DesignModeContext();

    Core::Context context() const;
    QWidget *widget();

    QString contextHelpId() const;

private:
    DesignModeWidget *m_widget;
    const Core::Context m_context;
};

class FormEditorContext : public Core::IContext
{
public:
    FormEditorContext(FormEditorWidget *widget);
    ~FormEditorContext();

    Core::Context context() const;
    QWidget *widget();

    QString contextHelpId() const;

private:
    FormEditorWidget *m_widget;
    const Core::Context m_context;
};

}
}

#endif // DESIGNMODECONTEXT_H

==> qt-creator-2.3.0-rc-src.zip: qt-creator-2.3.0-rc-src/src/plugins/qmldesigner/designmodecontext.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef DESIGNMODECONTEXT_H
#define DESIGNMODECONTEXT_H

#include <coreplugin/icontext.h>

namespace QmlDesigner {
namespace Internal {

/**
  * Bauhaus Design mode context object
  */
class DesignModeContext : public Core::IContext
{
public:
    DesignModeContext(QWidget *widget);
    QString contextHelpId() const;
};

class FormEditorContext : public Core::IContext
{
public:
    FormEditorContext(QWidget *widget);
    QString contextHelpId() const;
};

class NavigatorContext : public Core::IContext
{
public:
    NavigatorContext(QWidget *widget);
    QString contextHelpId() const;
};

}
}

#endif // DESIGNMODECONTEXT_H
